<?php

/**
 * The admin-facing functionality of the plugin.
 *
 * @link       https://themeatelier.net
 * @since      1.0.0
 *
 * @package event-venue-showcase
 * @subpackage event-venue-showcase/Admin/Views
 * @author     ThemeAtelier<themeatelierbd@gmail.com>
 */

namespace ThemeAtelier\EventVenueShowcase\Admin;

use ThemeAtelier\EventVenueShowcase\Admin\Views\Views;
use ThemeAtelier\EventVenueShowcase\Admin\Settings\Settings;

/**
 * The admin class
 */
class Admin
{
	/**
	 * The slug of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_slug   The slug of this plugin.
	 */
	private $plugin_slug;

	/**
	 * The min of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $min   The slug of this plugin.
	 */
	private $min;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The class constructor.
	 *
	 * @param string $plugin_slug The slug of the plugin.
	 * @param string $version Current version of the plugin.
	 */
	function __construct($plugin_slug, $version)
	{
		$this->plugin_slug = $plugin_slug;
		$this->version     = $version;
		$this->min         = defined('WP_DEBUG') && WP_DEBUG ? '' : '.min';

		Views::metaboxes('evs_venue_metaboxes'); // Generator metaboxes.
		Views::view_heading('evs_venue_header'); // Heading Style.
		Settings::options('evs_venue_settings'); // Setting options.
	}

	/**
	 * Register event_venue custom post type
	 *
	 * @since    1.0.0
	 */
	public function shortcode_post_type()
	{
		$labels     = array(
			'name'               => esc_html__('Event Venue', 'event-venue-showcase'),
			'singular_name'      => esc_html__('Event Venue', 'event-venue-showcase'),
			'add_new'            => esc_html__('Add New', 'event-venue-showcase'),
			'add_new_item'       => esc_html__('Add New Event Venue', 'event-venue-showcase'),
			'edit_item'          => esc_html__('Edit Venue', 'event-venue-showcase'),
			'new_item'           => esc_html__('New Venue', 'event-venue-showcase'),
			'all_items'          => esc_html__('Event Venue', 'event-venue-showcase'),
			'view_item'          => esc_html__('View Event Venue Shortcode', 'event-venue-showcase'),
			'search_items'       => esc_html__('Search Event Venue Shortcode', 'event-venue-showcase'),
			'not_found'          => esc_html__('No Event Venue Shortcode Found', 'event-venue-showcase'),
			'not_found_in_trash' => esc_html__('No Event Venue Shortcode Found in Trash', 'event-venue-showcase'),
			'parent_item_colon'  => null,
			'menu_name'          => esc_html__('Event Venue', 'event-venue-showcase'),
		);
		$menu_icon  = 'data:image/svg+xml;base64,' . base64_encode(
			'<svg width="48" height="48" viewBox="0 0 48 48" fill="none" xmlns="http://www.w3.org/2000/svg">
			<path d="M15.5 10.7666C14.6716 10.7666 14 11.4382 14 12.2666C14 13.095 14.6716 13.7666 15.5 13.7666C16.3284 13.7666 17 13.095 17 12.2666C17 11.4382 16.3284 10.7666 15.5 10.7666Z" fill="#8E8E8E"/>
			<path fill-rule="evenodd" clip-rule="evenodd" d="M15.5 36L26.8062 17.6876C31.6876 9.7813 25.4352 0 15.5 0C5.56479 0 -0.687625 9.7813 4.19378 17.6876L15.5 36ZM11 12.2666C11 9.78132 13.0147 7.7666 15.5 7.7666C17.9853 7.7666 20 9.78132 20 12.2666C20 14.7519 17.9853 16.7666 15.5 16.7666C13.0147 16.7666 11 14.7519 11 12.2666Z" fill="#8E8E8E"/>
			<path d="M5.16295 30.9284C5.81916 30.4228 5.94122 29.4809 5.43558 28.8247C4.92993 28.1685 3.98806 28.0464 3.33185 28.5521C1.37839 30.0573 0 32.0989 0 34.5007C0 37.4805 2.09999 39.8849 4.85629 41.46C7.65503 43.0592 11.4213 44.0007 15.5 44.0007C19.5787 44.0007 23.345 43.0592 26.1437 41.46C28.9 39.8849 31 37.4805 31 34.5007C31 32.0989 29.6216 30.0573 27.6682 28.5521C27.0119 28.0464 26.0701 28.1685 25.5644 28.8247C25.0588 29.4809 25.1808 30.4228 25.8371 30.9284C27.3362 32.0836 28 33.3361 28 34.5007C28 35.9393 26.966 37.5348 24.6553 38.8552C22.387 40.1514 19.1533 41.0007 15.5 41.0007C11.8467 41.0007 8.61297 40.1514 6.34471 38.8552C4.03401 37.5348 3 35.9393 3 34.5007C3 33.3361 3.66381 32.0836 5.16295 30.9284Z" fill="#8E8E8E"/>
			</svg>
			'
		);
		$capability = apply_filters('evs_venue_ui_permission', 'manage_options');
		$show_ui    = current_user_can($capability) ? true : false;
		register_post_type(
			'event_venue',
			array(
				'labels'              => $labels,
				'capability_type'     => 'post',
				'supports'            => array('title'),
				'show_in_menu'        => true,
				'menu_position'       => 56,
				'menu_icon'           => $menu_icon,
				'public'              => true,
				'publicly_queryable'  => false,
				'show_ui'             => $show_ui,
				'exclude_from_search' => true,
				'show_in_nav_menus'   => false,
				'has_archive'         => false,
				'rewrite'             => false,
				'show_in_rest'        => true,
			)
		);
	}

	/**
	 * Customize venue taxonomies update messages.
	 *
	 * @param array $messages The venue taxonomy message.
	 * @since 1.0.0
	 * @return bool
	 */
	public static function update_venue_term_messages($messages)
	{
		$messages['evs_venue'] = array(
			0 => '',
			1 => esc_html__('Event Venue added.', 'event-venue-showcase'),
			2 => esc_html__('Event Venue deleted.', 'event-venue-showcase'),
			3 => esc_html__('Event Venue updated.', 'event-venue-showcase'),
		);

		return $messages;
	}


	/**
	 * Post update messages for ShortCode Generator.
	 *
	 * @param string $message The post update message for the post type event_venue.
	 * @return statement
	 */
	public function post_update_message($message)
	{
		$screen = get_current_screen();
		if ('event_venue' === $screen->post_type) {
			$message['post'][1] = esc_html__('View updated.', 'event-venue-showcase');
			$message['post'][6] = esc_html__('View published.', 'event-venue-showcase');
		}

		return $message;
	}

	/**
	 * Register the styles for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{
		$current_screen    = get_current_screen();
		$current_post_type = $current_screen->post_type;
		if ('event_venue' === $current_post_type) {
			wp_enqueue_style('evs-admin-styles', plugin_dir_url(__FILE__) . '/assets/css/event-venue-showcase-admin' . $this->min . '.css', array(), $this->version, 'all');
		}
	}
	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{
		$current_screen    = get_current_screen();
		$current_post_type = $current_screen->post_type;
		if ('event_venue' === $current_post_type) {
			wp_enqueue_script('evs-admin-js', plugin_dir_url(__FILE__) . '/assets/js/event-venue-showcase-admin' . $this->min . '.js', array('jquery'), $this->version, true);
		}
	}

	/**
	 * Rename columns in all Event Venue page
	 *
	 * @since    1.0.0
	 * @param  mixed $columns columns of all venue page.
	 */
	public function set_venue_custom_column($columns)
	{
		return array(
			'cb'        => '<input type="checkbox" />',
			'title'     => esc_html__('Name', 'event-venue-showcase'),
			'shortcode' => esc_html__('Shortcode', 'event-venue-showcase'),
			'date'      => esc_html__('Date', 'event-venue-showcase'),
		);
	}

	/**
	 * Get Shortcode generator columns.
	 *
	 * @since    1.0.0
	 * @param  mixed   $column columns of all venue page.
	 * @param integer $post_id post id of venue.
	 */
	public function get_venue_custom_column($column, $post_id)
	{
		switch ($column) {
			case 'shortcode':
				echo '<div class="evs-after-copy-text"><i class="fa fa-check-circle"></i> ' . esc_html__('Shortcode Copied to Clipboard!', 'event-venue-showcase') . ' </div>';
				echo "<input class='evs_input' style='width: 230px; padding: 6px;' readonly='readonly' type='text' onclick='this.select()' value='";
				echo '[event_venue id="' . esc_html($post_id) . '"]';
				echo "'/>";
			default:
				echo '';
		}
	}
}
