<?php
/**
 * Framework border field file.
 *
 * @link       https://themeatelier.net
 * @since      1.0.0
 *
 * @package    event-venue-showcase
 * @author     ThemeAtelier <themeatelierbd@gmail.com>
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access directly.

if ( ! class_exists( 'EVS_Field_border' ) ) {
	/**
	 *
	 * Field: border
	 *
	 * @since 1.0.0
	 * @version 1.0.0
	 */
	class EVS_Field_border extends EVS_Fields {
		/**
		 * Field constructor.
		 *
		 * @param array  $field The field type.
		 * @param string $value The values of the field.
		 * @param string $unique The unique ID for the field.
		 * @param string $where To where show the output CSS.
		 * @param string $parent The parent args.
		 */
		public function __construct( $field, $value = '', $unique = '', $where = '', $parent = '' ) {
			parent::__construct( $field, $value, $unique, $where, $parent );
		}
		/**
		 * Render field
		 *
		 * @return void
		 */
		public function render() {

			$args = wp_parse_args(
				$this->field,
				array(
					'top_icon'           => '<i class="fas fa-long-arrow-alt-up"></i>',
					'left_icon'          => '<i class="fas fa-long-arrow-alt-left"></i>',
					'bottom_icon'        => '<i class="fas fa-long-arrow-alt-down"></i>',
					'right_icon'         => '<i class="fas fa-long-arrow-alt-right"></i>',
					'all_icon'           => '<i class="fas fa-arrows-alt"></i>',
					'top_placeholder'    => esc_html__( 'top', 'event-venue-showcase' ),
					'right_placeholder'  => esc_html__( 'right', 'event-venue-showcase' ),
					'bottom_placeholder' => esc_html__( 'bottom', 'event-venue-showcase' ),
					'left_placeholder'   => esc_html__( 'left', 'event-venue-showcase' ),
					'all_placeholder'    => esc_html__( 'all', 'event-venue-showcase' ),
					'top'                => true,
					'left'               => true,
					'bottom'             => true,
					'right'              => true,
					'all'                => false,
					'color'              => true,
					'hover_color'        => true,
					'style'              => true,
					'unit'               => 'px',
				)
			);

			$default_value = array(
				'top'         => '',
				'right'       => '',
				'bottom'      => '',
				'left'        => '',
				'color'       => '',
				'hover_color' => '',
				'style'       => 'solid',
				'all'         => '',
			);

			$border_props = array(
				'solid'  => esc_html__( 'Solid', 'event-venue-showcase' ),
				'dashed' => esc_html__( 'Dashed', 'event-venue-showcase' ),
				'dotted' => esc_html__( 'Dotted', 'event-venue-showcase' ),
				'double' => esc_html__( 'Double', 'event-venue-showcase' ),
				'inset'  => esc_html__( 'Inset', 'event-venue-showcase' ),
				'outset' => esc_html__( 'Outset', 'event-venue-showcase' ),
				'groove' => esc_html__( 'Groove', 'event-venue-showcase' ),
				'ridge'  => esc_html__( 'Ridge', 'event-venue-showcase' ),
				'none'   => esc_html__( 'None', 'event-venue-showcase' ),
			);

			$default_value = ( ! empty( $this->field['default'] ) ) ? wp_parse_args( $this->field['default'], $default_value ) : $default_value;

			$value = wp_parse_args( $this->value, $default_value );

			echo wp_kses_post( $this->field_before() );

			echo '<div class="evs--inputs" data-depend-id="' . esc_attr( $this->field['id'] ) . '">';

			if ( ! empty( $args['all'] ) ) {

				$placeholder = ( ! empty( $args['all_placeholder'] ) ) ? ' placeholder="' . esc_attr( $args['all_placeholder'] ) . '"' : '';

				echo '<div class="evs--border">';
				echo '<div class="evs--title">' . esc_html__( 'Width', 'event-venue-showcase' ) . '</div>';
				echo '<div class="evs--input">';
				echo ( ! empty( $args['all_icon'] ) ) ? '<span class="evs--label evs--icon">' . wp_kses_post( $args['all_icon'] ) . '</span>' : '';
				echo '<input type="number" name="' . esc_attr( $this->field_name( '[all]' ) ) . '" value="' . esc_attr( $value['all'] ) . '"' . $placeholder . ' class="evs-input-number evs--is-unit" step="any" />';//phpcs:ignore
				echo ( ! empty( $args['unit'] ) ) ? '<span class="evs--label evs--unit">' . esc_attr( $args['unit'] ) . '</span>' : '';
				echo '</div>';
				echo '</div>';

			} else {

				$properties = array();

				foreach ( array( 'top', 'right', 'bottom', 'left' ) as $prop ) {
					if ( ! empty( $args[ $prop ] ) ) {
						$properties[] = $prop;
					}
				}

				$properties = ( array( 'right', 'left' ) === $properties ) ? array_reverse( $properties ) : $properties;

				foreach ( $properties as $property ) {

					$placeholder = ( ! empty( $args[ $property . '_placeholder' ] ) ) ? ' placeholder="' . esc_attr( $args[ $property . '_placeholder' ] ) . '"' : '';

					echo '<div class="evs--border">';
					echo '<div class="evs--title">' . esc_html__( 'Width', 'event-venue-showcase' ) . '</div>';
					echo '<div class="evs--input">';
					echo ( ! empty( $args['all_icon'] ) ) ? '<span class="evs--label evs--icon">' . wp_kses_post( $args['all_icon'] ) . '</span>' : '';
					echo '<input type="number" name="' . esc_attr( $this->field_name( '[all]' ) ) . '" value="' . esc_attr( $value['all'] ) . '"' . $placeholder . ' class="evs-input-number evs--is-unit" step="any" />';//phpcs:ignore
					echo ( ! empty( $args['unit'] ) ) ? '<span class="evs--label evs--unit">' . esc_attr( $args['unit'] ) . '</span>' : '';
					echo '</div>';
					echo '</div>';

				}
			}

			if ( ! empty( $args['style'] ) ) {
				echo '<div class="evs--border">';
				echo '<div class="evs--title">' . esc_html__( 'Style', 'event-venue-showcase' ) . '</div>';
				echo '<div class="evs--input">';
				echo '<select name="' . esc_attr( $this->field_name( '[style]' ) ) . '">';
				foreach ( $border_props as $border_prop_key => $border_prop_value ) {
					$selected = ( $value['style'] === $border_prop_key ) ? ' selected' : '';
					echo '<option value="' . esc_attr( $border_prop_key ) . '"' . esc_attr( $selected ) . '>' . esc_attr( $border_prop_value ) . '</option>';
				}
				echo '</select>';
				echo '</div>';
				echo '</div>';
			}

			echo '</div>';

			if ( ! empty( $args['color'] ) ) {
				$default_color_attr = ( ! empty( $default_value['color'] ) ) ? ' data-default-color="' . esc_attr( $default_value['color'] ) . '"' : '';
				echo '<div class="evs--color">';
				echo '<div class="evs-field-color">';
				echo '<div class="evs--title">' . esc_html__( 'Color', 'event-venue-showcase' ) . '</div>';
				echo '<input type="text" name="' . esc_attr( $this->field_name( '[color]' ) ) . '" value="' . esc_attr( $value['color'] ) . '" class="evs-color"' . $default_color_attr . ' />';//phpcs:ignore
				echo '</div>';
				echo '</div>';
			}

			if ( ! empty( $args['hover_color'] ) ) {
				$default_color_attr = ( ! empty( $default_value['hover_color'] ) ) ? ' data-default-color="' . esc_attr( $default_value['hover_color'] ) . '"' : '';
				echo '<div class="evs--color">';
				echo '<div class="evs-field-color">';
				echo '<div class="evs--title">' . esc_html__( 'Hover Color', 'event-venue-showcase' ) . '</div>';
				echo '<input type="text" name="' . esc_attr( $this->field_name( '[hover_color]' ) ) . '" value="' . esc_attr( $value['hover_color'] ) . '" class="evs-color"' . $default_color_attr . ' />'; //phpcs:ignore
				echo '</div>';
				echo '</div>';
			}

			echo wp_kses_post( $this->field_after() );
		}

	}
}
