<?php

/**
 * Carousel Controls tab.
 *
 * @since      1.0.0
 *
 * @package event-venue-showcase
 * @subpackage event-venue-showcase/Admin/Views
 * @author     ThemeAtelier<themeatelierbd@gmail.com>
 */

namespace ThemeAtelier\EventVenueShowcase\Admin\Views;

use ThemeAtelier\EventVenueShowcase\Admin\Framework\Classes\EVS;

// Cannot access directly.
if (!defined('ABSPATH')) {
	die;
}

/**
 * This class is responsible for General tab in Event Venue Views page.
 *
 * @since      1.0.0
 */
class Carousel
{

	/**
	 * Carousel settings.
	 *
	 * @since 1.0.0
	 * @param string $prefix evs_venue_metaboxes.
	 */
	public static function section($prefix)
	{
		EVS::createSection(
			$prefix,
			array(
				'title'  => esc_html__('Carousel Controls', 'event-venue-showcase'),
				'icon'   => 'fa fa-sliders',
				'fields' => array(
					array(
						'id'         => 'carousel_autoplay',
						'type'       => 'switcher',
						'title'      => esc_html__('AutoPlay', 'event-venue-showcase'),
						'subtitle'   => esc_html__('On/Off auto play.', 'event-venue-showcase'),
						'text_on'    => esc_html__('Enabled', 'event-venue-showcase'),
						'text_off'   => esc_html__('Disabled', 'event-venue-showcase'),
						'text_width' => 96,
						'default'    => 'true',
					),
					array(
						'id'         => 'carousel_autoplay_speed',
						'type'       => 'spinner',
						'title'      => esc_html__('AutoPlay Speed', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Set autoplay speed in millisecond.', 'event-venue-showcase'),
						'default'    => 2000,
						'unit'       => 'ms',
						'max'		 => 5000,
						'min'		 => 500,
						'step'		 => 100,
						'dependency' => array('carousel_autoplay', '==', 'true', true),
					),
					array(
						'id'      => 'carousel_sliding_speed',
						'type'    => 'spinner',
						'title'   => esc_html__('Sliding Speed', 'event-venue-showcase'),
						'text_on' => esc_html__('Enabled', 'event-venue-showcase'),
						'default' => 400,
						'max'		 => 1000,
						'min'		 => 200,
						'step'		 => 50,
						'unit'    => 'ms',
					),
					array(
						'id'         => 'carousel_pause_on_hover',
						'type'       => 'switcher',
						'title'      => esc_html__('Pause on Hover', 'event-venue-showcase'),
						'subtile'    => esc_html__('On/Off carousel pause on hover.', 'event-venue-showcase'),
						'subtitle'   => esc_html__('On/Off Pause on Hover.', 'event-venue-showcase'),
						'text_on'    => esc_html__('Enabled', 'event-venue-showcase'),
						'text_off'   => esc_html__('Disabled', 'event-venue-showcase'),
						'text_width' => 96,
						'default'    => 'true',
					),
					array(
						'id'         => 'carousel_infinite_loop',
						'type'       => 'switcher',
						'title'      => esc_html__('Infinite Loop', 'event-venue-showcase'),
						'subtitle'   => esc_html__('On/Off Infinite Loop.', 'event-venue-showcase'),
						'text_on'    => esc_html__('Enabled', 'event-venue-showcase'),
						'text_off'   => esc_html__('Disabled', 'event-venue-showcase'),
						'text_width' => 96,
						'default'    => 'true',
					),
					array(
						'id'       => 'number_of_venue_to_scroll',
						'type'     => 'column',
						'title'    => esc_html__('Slide To Scroll', 'event-venue-showcase'),
						'subtitle' => esc_html__('Number of venue(s) to scroll at a time.', 'event-venue-showcase'),
						'unit'     => false,
						'default'  => array(
							'large_desktop' => '1',
							'desktop'       => '1',
							'laptop'        => '1',
							'tablet'        => '1',
							'mobile'        => '1',
						),
					),
					array(
						'id'         => 'carousel_navigation',
						'type'       => 'switcher',
						'title'      => esc_html__('Navigation', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Show/Hide carousel navigation.', 'event-venue-showcase'),
						'text_on'    => esc_html__('Show', 'event-venue-showcase'),
						'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
						'default'    => true,
						'text_width' => 75,
					),
					array(
						'id'         => 'carousel_navigation_color',
						'type'       => 'color_group',
						'title'      => esc_html__('Navigation Color', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Set color for the carousel navigation.', 'event-venue-showcase'),
						'options'    => array(
							'color'          => esc_html__('Color', 'event-venue-showcase'),
							'hover_color'    => esc_html__('Hover Color', 'event-venue-showcase'),
							'bg_color'       => esc_html__('Background', 'event-venue-showcase'),
							'bg_hover_color' => esc_html__('Hover Background', 'event-venue-showcase'),
						),
						'default'    => array(
							'color'          => '#aaaaaa',
							'hover_color'    => '#ffffff',
							'bg_color'       => 'transparent',
							'bg_hover_color' => '#5c4aee',
						),
						'dependency' => array('carousel_navigation', '==', 'true', true),
					),
					array(
						'id'         => 'carousel_pagination',
						'type'       => 'switcher',
						'title'      => esc_html__('Pagination', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Show/Hide carousel pagination.', 'event-venue-showcase'),
						'text_on'    => esc_html__('Show', 'event-venue-showcase'),
						'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
						'default'    => true,
						'text_width' => 75,
					),
					array(
						'id'         => 'carousel_pagination_color',
						'type'       => 'color_group',
						'title'      => esc_html__('Pagination Color', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Set color for the carousel Pagination.', 'event-venue-showcase'),
						'options'    => array(
							'color'        => esc_html__('Color', 'event-venue-showcase'),
							'active_color' => esc_html__('Active Color', 'event-venue-showcase'),
						),
						'default'    => array(
							'color'        => '#aaaaaa',
							'active_color' => '#5c4aee',
						),
						'dependency' => array('carousel_pagination', '==', 'true', true),
					),
				),
			)
		);
	}
}
