<?php

/**
 * DetailPageSetting tab.
 *
 * @since      1.0.0
 *
 * @package event-venue-showcase
 * @subpackage event-venue-showcase/Admin/Views
 * @author     ThemeAtelier<themeatelierbd@gmail.com>
 */

namespace ThemeAtelier\EventVenueShowcase\Admin\Views;

use ThemeAtelier\EventVenueShowcase\Admin\Framework\Classes\EVS;

// Cannot access directly.
if (!defined('ABSPATH')) {
	die;
}

/**
 * This class is responsible for DetailPageSetting tab in Event Venue Views page.
 *
 * @since      1.0.0
 */
class DetailPageSetting
{

	/**
	 * DetailPageSetting settings.
	 *
	 * @since 1.0.0
	 * @param string $prefix evs_venue_metaboxes.
	 */
	public static function section($prefix, $option)
	{
		EVS::createSection(
			$prefix,
			array(
				'title'  => esc_html__('Detail Page Setting', 'event-venue-showcase'),
				'icon'   => 'fa fa-gear',
				'fields' => array(
					array(
						'id'       => 'evs_page_link_type',
						'type'     => 'radio',
						'title'    => esc_html__('Detail Page Link Type', 'event-venue-showcase'),
						'subtitle' => esc_html__('Choose a link type for the (item) detail page.', 'event-venue-showcase'),
						'options'  => $option,
						'default'  => 'popup',
					),
					array(
						'id'         => 'evs_link_target',
						'type'       => 'radio',
						'title'      => esc_html__('Target', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Open post (item) in', 'event-venue-showcase'),
						'options'    => array(
							'_self'   => esc_html__('Current Tab', 'event-venue-showcase'),
							'_blank'  => esc_html__('New Tab', 'event-venue-showcase'),
							'_parent' => esc_html__('Parent', 'event-venue-showcase'),
							'_top'    => esc_html__('Top', 'event-venue-showcase'),
						),
						'default'    => '_self',
						'dependency' => array('evs_page_link_type', '==', 'single_page'),
					),
					array(
						'id'      => 'evs_link_rel',
						'type'    => 'checkbox',
						'title'   => esc_html__('Add rel="nofollow" to item links', 'event-venue-showcase'),
						'default' => 'false',
					),
					array(
						'id'         => 'evs_popup_type',
						'type'       => 'radio',
						'title'      => esc_html__('Popup Type', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Choose a popup type.', 'event-venue-showcase'),
						'options'    => array(
							'single_popup' => esc_html__('Single Popup', 'event-venue-showcase'),
							'multi_popup'  => esc_html__('Multi Popup (Preview with navigation)', 'event-venue-showcase'),
						),
						'default'    => 'single_popup',
						'dependency' => array('evs_page_link_type', '==', 'popup'),
					),
					array(
						'id'         => 'popup_width',
						'type'       => 'spacing',
						'title'      => esc_html__('Maximum Width', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Set maximum popup width.', 'event-venue-showcase'),
						'sanitize'   => 'evs_sanitize_number_array_field',
						'all'        => true,
						'min'        => 0,
						'max'        => 3000,
						'all_icon'   => '<i class="fa fa-arrows-h"></i>',
						'units'      => array('px', '%'),
						'default'    => array(
							'all' => '800',
						),
						'dependency' => array('evs_page_link_type', '==', 'popup'),
					),
					array(
						'id'         => 'popup_height',
						'type'       => 'spacing',
						'title'      => esc_html__('Maximum Height', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Set maximum popup height.', 'event-venue-showcase'),
						'sanitize'   => 'evs_sanitize_number_array_field',
						'all'        => true,
						'min'        => 0,
						'max'        => 3000,
						'all_icon'   => '<i class="fa fa-arrows-v"></i>',
						'units'      => array('vh', 'px', '%'),
						'default'    => array(
							'all' => '700',
						),
						'dependency' => array('evs_page_link_type', '==', 'popup'),
					),
					array(
						'id'         => 'popup_bg_color',
						'type'       => 'color',
						'title'      => esc_html__('Background Color', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Change the popup background color.', 'event-venue-showcase'),
						'default'    => '#fff',
						'dependency' => array('evs_page_link_type', '==', 'popup'),
					),
					array(
						'id'       => 'popup_border_radius',
						'type'     => 'spacing',
						'title'    => esc_html__('Border Radius', 'event-venue-showcase'),
						'subtitle' => esc_html__('Set popup border radius.', 'event-venue-showcase'),
						'top'      => false,
						'bottom'   => false,
						'left'     => false,
						'right'    => false,
						'all'      => true,
						'units'    => array('px', '%'),
						'default'  => array(
							'all'  => '10',
							'unit' => 'px',
						),
						'dependency' => array('evs_page_link_type', '==', 'popup'),
					),
					array(
						'id'         => 'popup_overlay_color',
						'type'       => 'color',
						'title'      => esc_html__('Overlay Color', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Change the popup overlay color.', 'event-venue-showcase'),
						'default'    => 'rgba(11,11,11,0.8)',
						'dependency' => array('evs_page_link_type', '==', 'popup'),
					),
					array(
						'id'         => 'popup_close_button',
						'type'       => 'switcher',
						'title'      => esc_html__('Close Button', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Show/Hide popup close button.', 'event-venue-showcase'),
						'text_on'    => esc_html__('Show', 'event-venue-showcase'),
						'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
						'text_width' => 80,
						'default'    => true,
						'dependency' => array('evs_page_link_type', '==', 'popup'),
					),
					array(
						'id'         => 'popup_close_button_color',
						'type'       => 'color_group',
						'title'      => esc_html__('Close Button Color', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Change the popup close button color.', 'event-venue-showcase'),
						'options'    => array(
							'color'       => esc_html__('Color', 'event-venue-showcase'),
							'hover-color' => esc_html__('Hover Color', 'event-venue-showcase'),
						),
						'default'    => array(
							'color'       => '#fc0c0c',
							'hover-color' => '#5c4aee',
						),
						'dependency' => array('evs_page_link_type|popup_close_button', '==|==', 'popup|true'),
					),
					array(
						'id'         => 'popup_nav_color',
						'type'       => 'color_group',
						'title'      => esc_html__('Navigation Color', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Change the popup navigation color.', 'event-venue-showcase'),
						'options'    => array(
							'color'       => esc_html__('Color', 'event-venue-showcase'),
							'hover-color' => esc_html__('Hover Color', 'event-venue-showcase'),
							'bg'          => esc_html__('Background', 'event-venue-showcase'),
							'hover-bg'    => esc_html__('Hover Background', 'event-venue-showcase'),
						),
						'default'    => array(
							'color'       => '#aaa',
							'hover-color' => '#fff',
							'bg'          => 'rgba(0,0,0,0.5)',
							'hover-bg'    => '#5c4aee',
						),
						'dependency' => array('evs_page_link_type|evs_popup_type', '==|==', 'popup|multi_popup'),
					),
					array(
						'id'       => 'popup_venue_sorter',
						'type'     => 'sortable',
						'title'    => esc_html__('Content Fields', 'event-venue-showcase'),
						'subtitle' => esc_html__('Item content fields which are draggable to change display order and it\'s settings.', 'event-venue-showcase'),
						'class'    => 'evs_content_sorter',
						'dependency' => array('evs_page_link_type', '==', 'popup'),
						'fields'   => array(
							array(
								'id'         => 'popup_evs_thumb',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Thumbnail', 'event-venue-showcase'),
										'fields' => array(
											array(
												'id'         => 'popup_show_venue_image',
												'type'       => 'switcher',
												'title'      => esc_html__('Venue Item Image', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Show/Hide venue item image.', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'default'    => true,
												'text_width' => 75,
											),
											array(
												'id'       => 'popup_evs_thumb_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'event-venue-showcase'),
												'sanitize' => 'popup_efp_sanitize_number_array_field',
												'units'    => array('px'),
												'min'      => -100,
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
												'dependency' => array('popup_show_venue_image', '==', 'true'),
											),
											array(
												'id'      => 'popup_evs_thumb_border',
												'type'    => 'border',
												'title'   => esc_html__('Border', 'event-venue-showcase'),
												'all'     => true,
												'default' => array(
													'all' => '0',
													'style' => 'solid',
													'color' => '#dddddd',
													'hover_color' => '#dddddd',
												),
												'dependency' => array('popup_show_venue_image', '==', 'true'),
											),
											array(
												'id'       => 'popup_image_venue_border_radius',
												'type'     => 'spacing',
												'title'    => esc_html__('Border Radius', 'event-venue-showcase'),
												'sanitize' => 'popup_evs_sanitize_number_array_field',
												'default'  => array(
													'top'    => '0',
													'right'  => '0',
													'bottom' => '0',
													'left'   => '0',
													'unit'   => 'px',
												),
												'dependency' => array('popup_show_venue_image', '==', 'true'),
											),

											array(
												'id'      => 'popup_evs_thumb_zoom',
												'type'    => 'select',
												'title'   => esc_html__('Zoom Effect', 'event-venue-showcase'),
												'options' => array(
													'none' => esc_html__('None', 'event-venue-showcase'),
													'zoom_in' => esc_html__('Zoom In', 'event-venue-showcase'),
													'zoom_out' => esc_html__('Zoom Out', 'event-venue-showcase'),
												),
												'default' => 'none',
												'dependency' => array('popup_show_venue_image', '==', 'true'),
											),
											array(
												'id'      => 'popup_evs_thumb_gray_scale',
												'type'    => 'select',
												'title'   => esc_html__('Image Mode', 'event-venue-showcase'),
												'options' => array(
													'none' => esc_html__('Normal', 'event-venue-showcase'),
													'gray_and_normal' => esc_html__('Grayscale and normal on hover', 'event-venue-showcase'),
													'gray_on_hover' => esc_html__('Grayscale on hover', 'event-venue-showcase'),
													'always_gray' => esc_html__('Always grayscale', 'event-venue-showcase'),
												),
												'default' => 'none',
												'dependency' => array('popup_show_venue_image', '==', 'true'),
											),
										),
									),
								),
							),
							array(
								'id'         => 'popup_evs_title',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Title', 'event-venue-showcase'),
										'fields' => array(
											array(
												'id'         => 'popup_show_venue_title',
												'type'       => 'switcher',
												'title'      => esc_html__('Venue Item Title', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Show/Hide venue item title.', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'default'    => true,
												'text_width' => 75,
											),
											array(
												'id'         => 'popup_event_count',
												'type'       => 'switcher',
												'title'      => esc_html__('Event Count', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Event count on this location', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'default'    => true,
												'text_width' => 75,
											),
											array(
												'id'       => 'popup_evs_title_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'event-venue-showcase'),
												'sanitize' => 'evs_sanitize_number_array_field',
												'min'      => -100,
												'units'    => array('px'),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
												'dependency' => array('popup_show_venue_title', '==', 'true'),
											),
										),
									),
								),
							),

							array(
								'id'         => 'popup_evs_address',
								'class'      => 'popup_evs_meta ta-product-not-fields',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Address', 'event-venue-showcase'),
										'fields' => array(
											array(
												'id'         => 'popup_show_venue_address',
												'type'       => 'switcher',
												'title'      => esc_html__('Venue Address', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Show/Hide venue address.', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'default'    => true,
												'text_width' => 75,
											),
											array(
												'id'         => 'popup_venue_address_icon',
												'type'       => 'icon',
												'title'      => esc_html__('Address Icon', 'event-venue-showcase'),
												'desc'   => esc_html__('Set icon before address.', 'event-venue-showcase'),
												'default' => 'fas fa-map-marker-alt',
												'dependency' => array('show_venue_address', '==', true)
											),
											array(
												'id'         => 'popup_venue_address',
												'type'       => 'select',
												'title'      => esc_html__('Select Address', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Select venue address.', 'event-venue-showcase'),
												'chosen'      => true,
												'multiple'    => true,
												'sortable'    => true,
												'options'     => array(
													'address'  => esc_html__('Address', 'event-venue-showcase'),
													'city'  => esc_html__('City', 'event-venue-showcase'),
													'country'  => esc_html__('Country', 'event-venue-showcase'),
													'state'  => esc_html__('State', 'event-venue-showcase'),
													'postal_code'  => esc_html__('Postal Code', 'event-venue-showcase'),
													'google_map'  => esc_html__('Google Map', 'event-venue-showcase'),
												),
												'default' => array('address', 'city', 'country', 'state', 'postal_code'),
												'dependency' => array('popup_show_venue_address', '==', true)
											),
											array(
												'id'            => 'popup_venue_google_mam_text',
												'type'          => 'text',
												'title'         => esc_html__('Google Map Text', 'event-venue-showcase'),
												'default'       => esc_html__('Google Map', 'event-venue-showcase'),
												'dependency'    => array('popup_show_venue_address|popup_venue_address', '==|any', 'true|google_map')
											),
											array(
												'id'       => 'popup_evs_address_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'event-venue-showcase'),
												'sanitize' => 'popup_evs_sanitize_number_array_field',
												'min'      => -100,
												'units'    => array('px'),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
												'dependency' => array('popup_show_venue_address', '==', 'true'),
											),
										),
									),
								),
							),
							array(
								'id'         => 'popup_evs_phone',
								'class'      => 'evs_event_fildes ta-product-not-fields',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Phone Number', 'event-venue-showcase'),
										'fields' => array(
											array(
												'id'         => 'popup_show_phone_number',
												'type'       => 'switcher',
												'title'      => esc_html__('Phone Number', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Show/Hide phone number.', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'default'    => true,
												'text_width' => 75,
											),
											array(
												'id'            => 'popup_phone_number_icon',
												'type'          => 'icon',
												'title'         => esc_html__('Phone Number Icon', 'event-venue-showcase'),
												'desc'          => esc_html__('Set icon before phone number.', 'event-venue-showcase'),
												'default'       => 'fas fa-phone-alt',
												'dependency'    => array('popup_show_phone_number', '==', 'true')
											),
											array(
												'id'       => 'popup_evs_phone_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'event-venue-showcase'),
												'sanitize' => 'popup_evs_sanitize_number_array_field',
												'units'    => array('px'),
												'min'      => -5,
												'dependency' => array('popup_show_phone_number', '==', 'true'),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
											),
										),
									),
								),
							),
							array(
								'id'         => 'popup_evs_website',
								'class'      => 'popup_evs_event_fildes ta-product-not-fields',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Website', 'event-venue-showcase'),
										'fields' => array(
											array(
												'id'         => 'popup_show_venue_website',
												'type'       => 'switcher',
												'title'      => esc_html__('Website', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Show/Hide website name.', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'default'    => true,
												'text_width' => 75,
											),
											array(
												'id'            => 'popup_website_icon',
												'type'          => 'icon',
												'title'         => esc_html__('Website Icon', 'event-venue-showcase'),
												'desc'          => esc_html__('Set icon before website.', 'event-venue-showcase'),
												'default'       => 'fas fa-external-link-alt',
												'dependency'    => array('popup_show_venue_website', '==', 'true')
											),
											array(
												'id'            => 'popup_website_text',
												'type'          => 'text',
												'title'         => esc_html__('Website Text', 'event-venue-showcase'),
												'desc'          => esc_html__('Set website text.', 'event-venue-showcase'),
												'default'       => esc_html__('Visit Website', 'event-venue-showcase'),
												'dependency'    => array('popup_show_venue_website', '==', 'true')
											),
											array(
												'id'       => 'popup_evs_website_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'event-venue-showcase'),
												'sanitize' => 'popup_evs_sanitize_number_array_field',
												'units'    => array('px'),
												'min'      => -5,
												'dependency' => array('popup_show_venue_website', '==', 'true'),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
											),
										),
									),
								),
							),
							array(
								'id'         => 'popup_evs_map',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Map', 'event-venue-showcase'),
										'fields' => array(
											array(
												'id'         => 'popup_show_venue_map',
												'type'       => 'switcher',
												'title'      => esc_html__('Venue Map', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Show/Hide venue map.', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'default'    => true,
												'text_width' => 75,
											),
											array(
												'id'         => 'popup_evs_map_dimension',
												'type'       => 'dimensions',
												'title'      => esc_html__('Height', 'event-venue-showcase'),
												'width'     => false,
												'default'  => array(
													'height' => '250',
													'unit'   => 'px',
												),
												'dependency' => array('popup_show_venue_map', '==', true)
											),
											array(
												'id'       => 'popup_evs_map_border_radius',
												'type'     => 'spacing',
												'title'    => esc_html__('Border Radius', 'event-venue-showcase'),
												'sanitize' => 'popup_evs_sanitize_number_array_field',
												'default'  => array(
													'top'    => '0',
													'right'  => '0',
													'bottom' => '0',
													'left'   => '0',
													'unit'   => 'px',
												),
												'dependency' => array('popup_show_venue_map', '==', 'true'),
											),

											array(
												'id'       => 'popup_evs_map_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'event-venue-showcase'),
												'sanitize' => 'popup_evs_sanitize_number_array_field',
												'units'    => array('px'),
												'min'      => -100,
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
												'dependency' => array('popup_show_venue_map', '==', 'true'),
											),
										),
									),
								),
							),
							array(
								'id'         => 'popup_evs_description',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html('Description', 'event-venue-showcase'),
										'fields' => array(
											array(
												'id'         => 'popup_show_venue_content',
												'type'       => 'switcher',
												'title'      => esc_html__('Venue Item Description', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Show/Hide venue item description.', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'default'    => false,
												'text_width' => 75,
											),
											array(
												'id'      => 'popup_evs_content_type',
												'type'    => 'select',
												'title'   => esc_html__('Content Display Type', 'event-venue-showcase'),
												'options' => array(
													'excerpt'      => esc_html__('Excerpt', 'event-venue-showcase'),
													'limit_content' => esc_html__('Content with Limit', 'event-venue-showcase'),
													'full_content' => esc_html__('Full Content', 'event-venue-showcase'),
												),
												'default' => 'limit_content',
												'dependency' => array('popup_show_venue_content', '==', 'true'),
											),
											array(
												'id'      => 'popup_evs_content_length_type',
												'type'    => 'button_set',
												'title'   => esc_html__('Content Length Type', 'event-venue-showcase'),
												'options' => array(
													'words'    => esc_html__('Words', 'event-venue-showcase'),
													'characters' => esc_html__('Characters', 'event-venue-showcase'),
												),
												'default' => 'words',
												'dependency' => array('popup_show_venue_content|popup_evs_content_type', '==|==', 'true|limit_content'),
											),
											array(
												'id'       => 'popup_evs_content_limit',
												'type'     => 'spinner',
												'title'    => esc_html__('Words Length', 'event-venue-showcase'),
												'sanitize' => 'evs_sanitize_number_field',
												'default'  => 30,
												'max'      => 10000,
												'dependency' => array('popup_show_venue_content|popup_evs_content_type|popup_evs_content_length_type', '==|==|==', 'true|limit_content|words'),
											),
											array(
												'id'       => 'popup_evs_content_characters_limit',
												'type'     => 'spinner',
												'title'    => esc_html__('Characters Length', 'event-venue-showcase'),
												'sanitize' => 'evs_sanitize_number_field',
												'default'  => 300,
												'max'      => 10000,
												'dependency' => array('popup_show_venue_content|popup_evs_content_type|popup_evs_content_length_type', '==|==|==', 'true|limit_content|characters'),
											),
											array(
												'id'      => 'popup_evs_content_ellipsis',
												'type'    => 'text',
												'title'   => esc_html__('Ellipsis Points Ending Excerpt', 'event-venue-showcase'),
												'default' => '...',
												'dependency' => array('popup_show_venue_content|popup_evs_content_type', '==|!=', 'true|full_content'),
											),
											array(
												'id'       => 'popup_evs_description_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'event-venue-showcase'),
												'sanitize' => 'popup_evs_sanitize_number_array_field',
												'units'    => array('px'),
												'min'      => -100,
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
												'dependency' => array('popup_show_venue_content', '==', 'true'),
											),
										),
									),
								),
							),
							array(
								'id'         => 'this_location_event',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html('This Location Event', 'event-venue-showcase'),
										'fields' => array(
											array(
												'id'         => 'show_current_venue_events',
												'type'       => 'switcher',
												'title'      => esc_html__('Current Venue Events', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Show/Hide current venue events', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'text_width' => 80,
												'default'    => true,
											),
											array(
												'id'         => 'show_events_title',
												'type'       => 'switcher',
												'title'      => esc_html__('Events Title', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Show/Hide current venue events', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'text_width' => 80,
												'default'    => true,
												'dependency' => array('show_current_venue_events', '==', 'true'),
											),
											array(
												'id'      => 'events_title_text',
												'type'    => 'text',
												'title'   => esc_html__('Event Title Text', 'event-venue-showcase'),
												'default' => esc_html__('Events from this venue', 'event-venue-showcase'),
												'dependency' => array('show_current_venue_events|show_events_title', '==|==', 'true|true'),
											),
											array(
												'id'      => 'par_page_event',
												'type'    => 'number',
												'title'   => esc_html__('Par Page Event', 'event-venue-showcase'),
												'default' => 3,
												'dependency' => array('show_current_venue_events', '==', 'true'),
											),
											array(
												'id'      => 'excerpt_length',
												'type'    => 'number',
												'title'   => esc_html__('Excerpt Length', 'event-venue-showcase'),
												'default' => 20,
												'dependency' => array('show_current_venue_events', '==', 'true'),
											),
											array(
												'id'      => 'show_lode_more_button',
												'type'    => 'switcher',
												'title'   => esc_html__('Lode More Button', 'event-venue-showcase'),
												'subtitle'   => esc_html__('Show/Hide lode more button', 'event-venue-showcase'),
												'text_on'    => esc_html__('Show', 'event-venue-showcase'),
												'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
												'text_width' => 80,
												'default'    => true,
												'dependency' => array('show_current_venue_events', '==', 'true'),
											),
											array(
												'id'      => 'lode_more_button_text',
												'type'    => 'text',
												'title'   => esc_html__('Lode More Button Text', 'event-venue-showcase'),
												'default' => esc_html__('Lode More', 'event-venue-showcase'),
												'dependency' => array('show_current_venue_events', '==', 'true'),
											),
										),
									),
								),
							),
						),
					),
				),
			)
		);
	}
}
