<?php

/**
 * Display tab.
 *
 * @since      1.0.0
 *
 * @package event-venue-showcase
 * @subpackage event-venue-showcase/Admin/Views
 * @author     ThemeAtelier<themeatelierbd@gmail.com>
 */

namespace ThemeAtelier\EventVenueShowcase\Admin\Views;

use ThemeAtelier\EventVenueShowcase\Admin\Framework\Classes\EVS;

// Cannot access directly.
if (!defined('ABSPATH')) {
    die;
}

/**
 * The Layout building class.
 */
class Display
{
    /**
     * Display options section metabox.
     *
     * @param string $prefix The metabox key.
     * @return void
     */
    public static function section($prefix)
    {
        EVS::createSection(
            $prefix,
            array(
                'title'  => esc_html__('Display Options', 'event-venue-showcase'),
                'icon'   => 'fa fa-th-large',
                'fields' => array(
                    array(
                        'id'         => 'show_venue_section_title',
                        'type'       => 'switcher',
                        'title'      => esc_html__('Venue Section Title', 'event-venue-showcase'),
                        'subtitle'   => esc_html__('Show/Hide Venue section title.', 'event-venue-showcase'),
                        'text_on'    => esc_html__('Show', 'event-venue-showcase'),
                        'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
                        'default'    => true,
                        'text_width' => 75,
                    ),
                    array(
                        'id'          => 'section_title_margin_around',
                        'type'        => 'spacing',
                        'title'       => esc_html__('Section Title Margin', 'event-venue-showcase'),
                        'subtitle'    => esc_html__('Set margin for section title.', 'event-venue-showcase'),
                        'output_mode' => 'margin',
                        'units'       => array(
                            esc_html__('px', 'event-venue-showcase'),
                            esc_html__('em', 'event-venue-showcase'),
                        ),
                        'default'     => array(
                            'top'    => '0',
                            'right'  => '0',
                            'bottom' => '30',
                            'left'   => '0',
                            'unit'   => 'px',
                        ),
                        'dependency'  => array(
                            'show_venue_section_title',
                            '==',
                            'true',
                        ),
                    ),
                    array(
                        'id'          => 'space_between_venue',
                        'type'        => 'spacing',
                        'title'       => esc_html__('Space Between Venue', 'event-venue-showcase'),
                        'subtitle'    => esc_html__('Set space in pixel between Venue.', 'event-venue-showcase'),
                        'output_mode' => 'margin',
                        'all'         => true,
                        'all_text'    => false,
                        'units'       => array(
                            esc_html__('px', 'event-venue-showcase'),
                        ),
                        'default'     => array(
                            'all'  => '20',
                            'unit' => 'px',
                        ),
                    ),
                    array(
                        'id'         => 'venue_item_color',
                        'type'       => 'color_group',
                        'title'      => esc_html__('Venue Item Color', 'event-venue-showcase'),
                        'subtitle'   => esc_html__('Set color and background form venue item.', 'event-venue-showcase'),
                        'options'           => array(
                            'color'         =>  esc_html__('Color', 'event-venue-showcase'),
                            'background'    =>  esc_html__('Background', 'event-venue-showcase'),
                            'hover_color'         =>  esc_html__('Hover Color', 'event-venue-showcase'),
                            'hover_background'    =>  esc_html__('Hover Background', 'event-venue-showcase'),
                        ),
                        'default'    => array(
                            'color'          => '#111827',
                            'background'    => 'transparent',
                            'hover_color'          => '#111827',
                            'hover_background'    => 'transparent',
                        ),
                    ),
                    array(
                        'id'         => 'venue_item_padding',
                        'type'       => 'spacing',
                        'title'      => esc_html__('Venue Item Padding', 'event-venue-showcase'),
                        'subtitle'   => esc_html__('Set padding form venue item.', 'event-venue-showcase'),
                        'default'  => array(
                            'top'    => '15',
                            'right'  => '15',
                            'bottom' => '15',
                            'left'   => '15',
                            'unit'   => 'px',
                        ),
                    ),
                    array(
                        'id'       => 'same_height',
                        'type'     => 'checkbox',
                        'title'    => esc_html__('Same Height', 'event-venue-showcase'),
                        'subtitle' => esc_html__('Check to make all items/slides the same height as the tallest one.', 'event-venue-showcase'),
                        'all'      => true,
                    ),
                    array(
                        'id'       => 'product_venue_border',
                        'type'     => 'border',
                        'title'    => esc_html__('Border', 'event-venue-showcase'),
                        'subtitle' => esc_html__('Set border for Event Venue.', 'event-venue-showcase'),
                        'all'      => true,
                        'default'  => array(
                            'all'         => '0',
                            'style'       => 'solid',
                            'color'       => '#ddd',
                            'hover_color' => '#ddd',
                        ),
                    ),
                    array(
                        'id'       => 'venue_border_radius',
                        'type'     => 'spacing',
                        'title'    => esc_html__('Radius', 'event-venue-showcase'),
                        'subtitle' => esc_html__('Set border radius.', 'event-venue-showcase'),
                        'top'      => false,
                        'bottom'   => false,
                        'left'     => false,
                        'right'    => false,
                        'all'      => true,
                        'units'    => array('px', '%'),
                        'default'  => array(
                            'all'  => '0',
                            'unit' => 'px',
                        ),
                    ),
                    array(
						'id'       => 'show_venue_box_shadow',
						'type'     => 'checkbox',
						'title'    => esc_html__('Box-Shadow', 'event-venue-showcase'),
						'subtitle' => esc_html__('Show box-shadow for the item.', 'event-venue-showcase'),
						'default'  => true,
					),
					array(
						'id'         => 'venue_box_shadow_property',
						'type'       => 'box_shadow',
						'title'      => esc_html__('Box-Shadow Values', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Set box-shadow property values for the item.', 'event-venue-showcase'),
						'default'    => array(
							'horizontal' => '0',
							'vertical'   => '0',
							'blur'       => '8',
							'spread'     => '-2',
							'color'      => 'rgb(187, 187, 187)',
						),
						'dependency' => array('show_venue_box_shadow', '==', 'true'),
					),
                    array(
                        'id'       => 'evs_content_sorter',
                        'type'     => 'sortable',
                        'title'    => esc_html__('Content Fields', 'event-venue-showcase'),
                        'subtitle' => esc_html__('Item content fields which are draggable to change display order and it\'s settings.', 'event-venue-showcase'),
                        'class'    => 'evs_content_sorter',
                        'fields'   => array(
                            array(
                                'id'         => 'evs_thumb',
                                'type'       => 'accordion',
                                'accordions' => array(
                                    array(
                                        'title'  => esc_html__('Thumbnail', 'event-venue-showcase'),
                                        'fields' => array(
                                            array(
                                                'id'         => 'show_venue_image',
                                                'type'       => 'switcher',
                                                'title'      => esc_html__('Venue Item Image', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Show/Hide venue item image.', 'event-venue-showcase'),
                                                'text_on'    => esc_html__('Show', 'event-venue-showcase'),
                                                'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
                                                'default'    => true,
                                                'text_width' => 75,
                                            ),
                                            array(
                                                'id'         => 'venue_image_size',
                                                'type'       => 'image_sizes',
                                                'title'      => esc_html__('Venue Image Size', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Set  venue image size.', 'event-venue-showcase'),
                                                'chosen'     => true,
                                                'default'    => 'medium_large',
                                                'dependency' => array('show_venue_image', '==', 'true'),
                                            ),
                                            array(
                                                'id'                => 'evs_custom_image_size',
                                                'type'              => 'dimensions_advanced',
                                                'title'             => esc_html__('Custom Size', 'event-venue-showcase'),
                                                'subtitle'          => esc_html__('Set a custom width and height of the venue logo.', 'event-venue-showcase'),
                                                'chosen'            => true,
                                                'bottom'            => false,
                                                'left'              => false,
                                                'color'             => false,
                                                'top_icon'          => '<i class="fa fa-arrows-h"></i>',
                                                'right_icon'        => '<i class="fa fa-arrows-v"></i>',
                                                'top_placeholder'   => 'width',
                                                'right_placeholder' => 'height',
                                                'styles'            => array(
                                                    'Hard-crop',
                                                    'Soft-crop',
                                                ),
                                                'default'           => array(
                                                    'top'   => '600',
                                                    'right' => '400',
                                                    'style' => 'Hard-crop',
                                                    'unit'  => 'px',
                                                ),
                                                'attributes'        => array(
                                                    'min' => 0,
                                                ),
                                                'dependency'        => array('venue_image_size|show_venue_image', '==|==', 'custom|true', true),
                                            ),
                                            array(
                                                'id'       => 'evs_thumb_margin',
                                                'type'     => 'spacing',
                                                'title'    => esc_html__('Margin', 'event-venue-showcase'),
                                                'sanitize' => 'efp_sanitize_number_array_field',
                                                'units'    => array('px'),
                                                'min'      => -100,
                                                'default'  => array(
                                                    'top'  => '0',
                                                    'right' => '0',
                                                    'bottom' => '15',
                                                    'left' => '0',
                                                ),
                                                'dependency' => array('show_venue_image', '==', 'true'),
                                            ),
                                            array(
                                                'id'      => 'evs_thumb_border',
                                                'type'    => 'border',
                                                'title'   => esc_html__('Border', 'event-venue-showcase'),
                                                'all'     => true,
                                                'default' => array(
                                                    'all' => '0',
                                                    'style' => 'solid',
                                                    'color' => '#dddddd',
                                                ),
                                                'dependency' => array('show_venue_image', '==', 'true'),
                                            ),
                                            array(
                                                'id'       => 'image_venue_border_radius',
                                                'type'     => 'spacing',
                                                'title'    => esc_html__('Border Radius', 'event-venue-showcase'),
                                                'sanitize' => 'evs_sanitize_number_array_field',
                                                'default'  => array(
                                                    'top'    => '0',
                                                    'right'  => '0',
                                                    'bottom' => '0',
                                                    'left'   => '0',
                                                    'unit'   => 'px',
                                                ),
                                                'dependency' => array('show_venue_image', '==', 'true'),
                                            ),

                                            array(
                                                'id'      => 'evs_thumb_zoom',
                                                'type'    => 'select',
                                                'title'   => esc_html__('Zoom Effect', 'event-venue-showcase'),
                                                'options' => array(
                                                    'none' => esc_html__('None', 'event-venue-showcase'),
                                                    'zoom_in' => esc_html__('Zoom In', 'event-venue-showcase'),
                                                    'zoom_out' => esc_html__('Zoom Out', 'event-venue-showcase'),
                                                ),
                                                'default' => 'none',
                                                'dependency' => array('show_venue_image', '==', 'true'),
                                            ),
                                            array(
                                                'id'      => 'evs_thumb_gray_scale',
                                                'type'    => 'select',
                                                'title'   => esc_html__('Image Mode', 'event-venue-showcase'),
                                                'options' => array(
                                                    'none' => esc_html__('Normal', 'event-venue-showcase'),
                                                    'gray_and_normal' => esc_html__('Grayscale and normal on hover', 'event-venue-showcase'),
                                                    'gray_on_hover' => esc_html__('Grayscale on hover', 'event-venue-showcase'),
                                                    'always_gray' => esc_html__('Always grayscale', 'event-venue-showcase'),
                                                ),
                                                'default' => 'none',
                                                'dependency' => array('show_venue_image', '==', 'true'),
                                            ),
                                        ),
                                    ),
                                ),
                            ),
                            array(
                                'id'         => 'evs_title',
                                'type'       => 'accordion',
                                'accordions' => array(
                                    array(
                                        'title'  => esc_html__('Title', 'event-venue-showcase'),
                                        'fields' => array(
                                            array(
                                                'id'         => 'show_venue_title',
                                                'type'       => 'switcher',
                                                'title'      => esc_html__('Venue Item Title', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Show/Hide venue item title.', 'event-venue-showcase'),
                                                'text_on'    => esc_html__('Show', 'event-venue-showcase'),
                                                'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
                                                'default'    => true,
                                                'text_width' => 75,
                                            ),
                                            array(
                                                'id'         => 'event_count',
                                                'type'       => 'switcher',
                                                'title'      => esc_html__('Event Count', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Event count on this location', 'event-venue-showcase'),
                                                'text_on'    => esc_html__('Show', 'event-venue-showcase'),
                                                'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
                                                'default'    => true,
                                                'text_width' => 75,
                                            ),
                                            array(
                                                'id'       => 'evs_title_margin',
                                                'type'     => 'spacing',
                                                'title'    => esc_html__('Margin', 'event-venue-showcase'),
                                                'sanitize' => 'evs_sanitize_number_array_field',
                                                'min'      => -100,
                                                'units'    => array('px'),
                                                'default'  => array(
                                                    'top'  => '0',
                                                    'right' => '0',
                                                    'bottom' => '15',
                                                    'left' => '0',
                                                ),
                                                'dependency' => array('show_venue_title', '==', 'true'),
                                            ),
                                        ),
                                    ),
                                ),
                            ),

                            array(
                                'id'         => 'evs_address',
                                'class'      => 'evs_meta ta-product-not-fields',
                                'type'       => 'accordion',
                                'accordions' => array(
                                    array(
                                        'title'  => esc_html__('Address', 'event-venue-showcase'),
                                        'fields' => array(
                                            array(
                                                'id'         => 'show_venue_address',
                                                'type'       => 'switcher',
                                                'title'      => esc_html__('Venue Address', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Show/Hide venue address.', 'event-venue-showcase'),
                                                'text_on'    => esc_html__('Show', 'event-venue-showcase'),
                                                'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
                                                'default'    => true,
                                                'text_width' => 75,
                                            ),
                                            array(
                                                'id'         => 'venue_address_icon',
                                                'type'       => 'icon',
                                                'title'      => esc_html__('Address Icon', 'event-venue-showcase'),
                                                'desc'   => esc_html__('Set icon before address.', 'event-venue-showcase'),
                                                'default' => 'fas fa-map-marker-alt',
                                                'dependency' => array('show_venue_address', '==', true)
                                            ),
                                            array(
                                                'id'         => 'venue_address',
                                                'type'       => 'select',
                                                'title'      => esc_html__('Select Address', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Select venue address.', 'event-venue-showcase'),
                                                'chosen'      => true,
                                                'multiple'    => true,
                                                'sortable'    => true,
                                                'options'     => array(
                                                    'address'  => esc_html__('Address', 'event-venue-showcase'),
                                                    'city'  => esc_html__('City', 'event-venue-showcase'),
                                                    'country'  => esc_html__('Country', 'event-venue-showcase'),
                                                    'state'  => esc_html__('State', 'event-venue-showcase'),
                                                    'postal_code'  => esc_html__('Postal Code', 'event-venue-showcase'),
                                                    'google_map'  => esc_html__('Google Map', 'event-venue-showcase'),
                                                ),
                                                'default' => array('address', 'city', 'country', 'state', 'postal_code'),
                                                'dependency' => array('show_venue_address', '==', true)
                                            ),
                                            array(
                                                'id'            => 'venue_google_mam_text',
                                                'type'          => 'text',
                                                'title'         => esc_html__('Google Map Text', 'event-venue-showcase'),
                                                'default'       => esc_html__('Google Map', 'event-venue-showcase'),
                                                'dependency'    => array('show_venue_address|venue_address', '==|any', 'true|google_map')
                                            ),
                                            array(
                                                'id'       => 'evs_address_margin',
                                                'type'     => 'spacing',
                                                'title'    => esc_html__('Margin', 'event-venue-showcase'),
                                                'sanitize' => 'evs_sanitize_number_array_field',
                                                'min'      => -100,
                                                'units'    => array('px'),
                                                'default'  => array(
                                                    'top'  => '0',
                                                    'right' => '0',
                                                    'bottom' => '15',
                                                    'left' => '0',
                                                ),
                                                'dependency' => array('show_venue_address', '==', 'true'),
                                            ),
                                        ),
                                    ),
                                ),
                            ),
                            array(
                                'id'         => 'evs_phone',
                                'class'      => 'evs_event_fildes ta-product-not-fields',
                                'type'       => 'accordion',
                                'accordions' => array(
                                    array(
                                        'title'  => esc_html__('Phone Number', 'event-venue-showcase'),
                                        'fields' => array(
                                            array(
                                                'id'         => 'show_phone_number',
                                                'type'       => 'switcher',
                                                'title'      => esc_html__('Phone Number', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Show/Hide phone number.', 'event-venue-showcase'),
                                                'text_on'    => esc_html__('Show', 'event-venue-showcase'),
                                                'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
                                                'default'    => true,
                                                'text_width' => 75,
                                            ),
                                            array(
                                                'id'            => 'phone_number_icon',
                                                'type'          => 'icon',
                                                'title'         => esc_html__('Phone Number Icon', 'event-venue-showcase'),
                                                'desc'          => esc_html__('Set icon before phone number.', 'event-venue-showcase'),
                                                'default'       => 'fas fa-phone-alt',
                                                'dependency'    => array('show_phone_number', '==', 'true')
                                            ),
                                            array(
                                                'id'       => 'evs_phone_margin',
                                                'type'     => 'spacing',
                                                'title'    => esc_html__('Margin', 'event-venue-showcase'),
                                                'sanitize' => 'evs_sanitize_number_array_field',
                                                'units'    => array('px'),
                                                'min'      => -5,
                                                'dependency' => array('show_phone_number', '==', 'true'),
                                                'default'  => array(
                                                    'top'  => '0',
                                                    'right' => '0',
                                                    'bottom' => '15',
                                                    'left' => '0',
                                                ),
                                            ),
                                        ),
                                    ),
                                ),
                            ),
                            array(
                                'id'         => 'evs_website',
                                'class'      => 'evs_event_fildes ta-product-not-fields',
                                'type'       => 'accordion',
                                'accordions' => array(
                                    array(
                                        'title'  => esc_html__('Website', 'event-venue-showcase'),
                                        'fields' => array(
                                            array(
                                                'id'         => 'show_venue_website',
                                                'type'       => 'switcher',
                                                'title'      => esc_html__('Website', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Show/Hide website name.', 'event-venue-showcase'),
                                                'text_on'    => esc_html__('Show', 'event-venue-showcase'),
                                                'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
                                                'default'    => true,
                                                'text_width' => 75,
                                            ),
                                            array(
                                                'id'            => 'website_icon',
                                                'type'          => 'icon',
                                                'title'         => esc_html__('Website Icon', 'event-venue-showcase'),
                                                'desc'          => esc_html__('Set icon before website.', 'event-venue-showcase'),
                                                'default'       => 'fas fa-external-link-alt',
                                                'dependency'    => array('show_venue_website', '==', 'true')
                                            ),
                                            array(
                                                'id'            => 'website_text',
                                                'type'          => 'text',
                                                'title'         => esc_html__('Website Text', 'event-venue-showcase'),
                                                'desc'          => esc_html__('Set website text.', 'event-venue-showcase'),
                                                'default'       => esc_html__( 'Visit Website', 'event-venue-showcase' ),
                                                'dependency'    => array('show_venue_website', '==', 'true')
                                            ),
                                            array(
                                                'id'       => 'evs_website_margin',
                                                'type'     => 'spacing',
                                                'title'    => esc_html__('Margin', 'event-venue-showcase'),
                                                'sanitize' => 'evs_sanitize_number_array_field',
                                                'units'    => array('px'),
                                                'min'      => -5,
                                                'dependency' => array('show_venue_website', '==', 'true'),
                                                'default'  => array(
                                                    'top'  => '0',
                                                    'right' => '0',
                                                    'bottom' => '15',
                                                    'left' => '0',
                                                ),
                                            ),
                                        ),
                                    ),
                                ),
                            ),
                            array(
                                'id'         => 'evs_map',
                                'type'       => 'accordion',
                                'accordions' => array(
                                    array(
                                        'title'  => esc_html__('Map', 'event-venue-showcase'),
                                        'fields' => array(
                                            array(
                                                'id'         => 'show_venue_map',
                                                'type'       => 'switcher',
                                                'title'      => esc_html__('Venue Map', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Show/Hide venue map.', 'event-venue-showcase'),
                                                'text_on'    => esc_html__('Show', 'event-venue-showcase'),
                                                'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
                                                'default'    => true,
                                                'text_width' => 75,
                                            ),
                                            array(
                                                'id'         => 'show_map_preloader',
                                                'type'       => 'switcher',
                                                'title'      => esc_html__('Preloader', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Show/Hide venue map.', 'event-venue-showcase'),
                                                'text_on'    => esc_html__('Show', 'event-venue-showcase'),
                                                'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
                                                'default'    => true,
                                                'text_width' => 75,
                                                'dependency' => array('show_venue_map', '==', true),
                                            ),
                                            array(
                                                'id'         => 'evs_map_dimension',
                                                'type'       => 'dimensions',
                                                'title'      => esc_html__('Height', 'event-venue-showcase'),
                                                'width'     => false,
                                                'default'  => array(
                                                    'height' => '120',
                                                    'unit'   => 'px',
                                                ),
                                                'dependency' => array('show_venue_map', '==', true)
                                            ),
                                            array(
                                                'id'       => 'evs_map_border_radius',
                                                'type'     => 'spacing',
                                                'title'    => esc_html__('Border Radius', 'event-venue-showcase'),
                                                'sanitize' => 'evs_sanitize_number_array_field',
                                                'default'  => array(
                                                    'top'    => '0',
                                                    'right'  => '0',
                                                    'bottom' => '0',
                                                    'left'   => '0',
                                                    'unit'   => 'px',
                                                ),
                                                'dependency' => array('show_venue_map', '==', 'true'),
                                            ),

                                            array(
                                                'id'       => 'evs_map_margin',
                                                'type'     => 'spacing',
                                                'title'    => esc_html__('Margin', 'event-venue-showcase'),
                                                'sanitize' => 'evs_sanitize_number_array_field',
                                                'units'    => array('px'),
                                                'min'      => -100,
                                                'default'  => array(
                                                    'top'  => '0',
                                                    'right' => '0',
                                                    'bottom' => '15',
                                                    'left' => '0',
                                                ),
                                                'dependency' => array('show_venue_map', '==', 'true'),
                                            ),
                                        ),
                                    ),
                                ),
                            ),
                            array(
                                'id'         => 'evs_description',
                                'type'       => 'accordion',
                                'accordions' => array(
                                    array(
                                        'title'  => esc_html('Description', 'event-venue-showcase'),
                                        'fields' => array(
                                            array(
                                                'id'         => 'show_venue_content',
                                                'type'       => 'switcher',
                                                'title'      => esc_html__('Venue Item Description', 'event-venue-showcase'),
                                                'subtitle'   => esc_html__('Show/Hide venue item description.', 'event-venue-showcase'),
                                                'text_on'    => esc_html__('Show', 'event-venue-showcase'),
                                                'text_off'   => esc_html__('Hide', 'event-venue-showcase'),
                                                'default'    => false,
                                                'text_width' => 75,
                                            ),
                                            array(
                                                'id'      => 'evs_content_type',
                                                'type'    => 'select',
                                                'title'   => esc_html__('Content Display Type', 'event-venue-showcase'),
                                                'options' => array(
                                                    'excerpt'      => esc_html__('Excerpt', 'event-venue-showcase'),
                                                    'limit_content' => esc_html__('Content with Limit', 'event-venue-showcase'),
                                                    'full_content' => esc_html__('Full Content', 'event-venue-showcase'),
                                                ),
                                                'default' => 'limit_content',
                                                'dependency' => array('show_venue_content', '==', 'true'),
                                            ),
                                            array(
                                                'id'      => 'evs_content_length_type',
                                                'type'    => 'button_set',
                                                'title'   => esc_html__('Content Length Type', 'event-venue-showcase'),
                                                'options' => array(
                                                    'words'    => esc_html__('Words', 'event-venue-showcase'),
                                                    'characters' => esc_html__('Characters', 'event-venue-showcase'),
                                                ),
                                                'default' => 'words',
                                                'dependency' => array('show_venue_content|evs_content_type', '==|==', 'true|limit_content'),
                                            ),
                                            array(
                                                'id'       => 'evs_content_limit',
                                                'type'     => 'spinner',
                                                'title'    => esc_html__('Words Length', 'event-venue-showcase'),
                                                'sanitize' => 'evs_sanitize_number_field',
                                                'default'  => 30,
                                                'max'      => 10000,
                                                'dependency' => array('show_venue_content|evs_content_type|evs_content_length_type', '==|==|==', 'true|limit_content|words'),
                                            ),
                                            array(
                                                'id'       => 'evs_content_characters_limit',
                                                'type'     => 'spinner',
                                                'title'    => esc_html__('Characters Length', 'event-venue-showcase'),
                                                'sanitize' => 'evs_sanitize_number_field',
                                                'default'  => 300,
                                                'max'      => 10000,
                                                'dependency' => array('show_venue_content|evs_content_type|evs_content_length_type', '==|==|==', 'true|limit_content|characters'),
                                            ),
                                            array(
                                                'id'      => 'evs_content_ellipsis',
                                                'type'    => 'text',
                                                'title'   => esc_html__('Ellipsis Points Ending Excerpt', 'event-venue-showcase'),
                                                'default' => '...',
                                                'dependency' => array('show_venue_content|evs_content_type', '==|!=', 'true|full_content'),
                                            ),
                                            array(
                                                'id'       => 'evs_description_margin',
                                                'type'     => 'spacing',
                                                'title'    => esc_html__('Margin', 'event-venue-showcase'),
                                                'sanitize' => 'evs_sanitize_number_array_field',
                                                'units'    => array('px'),
                                                'min'      => -100,
                                                'default'  => array(
                                                    'top'  => '0',
                                                    'right' => '0',
                                                    'bottom' => '15',
                                                    'left' => '0',
                                                ),
                                                'dependency' => array('show_venue_content', '==', 'true'),
                                            ),
                                        ),
                                    ),
                                ),
                            ),
                        ),
                    ),
                ),
            )
        ); // Display settings section end.
    }
}
