<?php

/**
 * General tab.
 *
 * @since      1.0.0
 *
 * @package event-venue-showcase
 * @subpackage event-venue-showcase/Admin/Views
 * @author     ThemeAtelier<themeatelierbd@gmail.com>
 */

namespace ThemeAtelier\EventVenueShowcase\Admin\Views;

use ThemeAtelier\EventVenueShowcase\Admin\Framework\Classes\EVS;

// Cannot access directly.
if (!defined('ABSPATH')) {
	die;
}

/**
 * This class is responsible for General tab in Event Venue Views page.
 *
 * @since      1.0.0
 */
class General
{

	/**
	 * General settings.
	 *
	 * @since 1.0.0
	 * @param string $prefix evs_venue_metaboxes.
	 */
	public static function section($prefix)
	{
		EVS::createSection(
			$prefix,
			array(
				'title'  => esc_html__('General Options', 'event-venue-showcase'),
				'icon'   => 'fa fa-gear',
				'fields' => array(
					array(
						'id'       => 'venue_layout_preset',
						'type'     => 'layout_preset',
						'class'    => 'evs_img_custom_width-3',
						'title'    => esc_html__('Layout', 'event-venue-showcase'),
						'subtitle' => esc_html__('Choose a layout', 'event-venue-showcase'),
						'options'  => array(
							'carousel_layout' => array(
								'image' => EVENT_VENUE_SHOWCASE_URL . '/includes/Admin/assets/img/carousel.png',
								'text'  => esc_html__('Carousel', 'event-venue-showcase'),
							),
						),
						'default'  => 'carousel_layout',
					),

					array(
						'id'          => 'evs_filter_venue',
						'type'        => 'select',
						'title'       => esc_html__('Filter Venues', 'event-venue-showcase'),
						'desc'       	=> esc_html__('Select an option to display by filtering venue.', 'event-venue-showcase'),
						'options'     => array(
							'all'  		=> esc_html__('All Venues', 'event-venue-showcase'),
							'specific'  => esc_html__('Specific Venues', 'event-venue-showcase'),
							'exclude'  	=> esc_html__('Exclude Venues', 'event-venue-showcase'),
						),
						'default'     => 'all'
					),
					array(
						'id'          => 'evs_specific_venue',
						'type'        => 'select',
						'title'       => esc_html__('Specific Venues', 'event-venue-showcase'),
						'desc'       	=> esc_html__('Select an option to display by filtering venue.', 'event-venue-showcase'),
						'chosen'      => true,
						'multiple'    => true,
						'sortable'    => true,
						'options'     => 'posts',
						'query_args'  => array(
							'post_type' => 'tribe_venue',
							'posts_per_page' => -1
						),
						'dependency' => array('evs_filter_venue', '==', 'specific'),
					),
					array(
						'id'          => 'evs_exclude_venue',
						'type'        => 'select',
						'title'       => esc_html__('Exclude Venues', 'event-venue-showcase'),
						'desc'       	=> esc_html__('Select an option to display by filtering venue.', 'event-venue-showcase'),
						'chosen'      => true,
						'multiple'    => true,
						'sortable'    => true,
						'options'     => 'posts',
						'query_args'  => array(
							'post_type' => 'tribe_venue',
							'posts_per_page' => -1
						),
						'dependency' => array('evs_filter_venue', '==', 'exclude'),
					),
					array(
						'id'         => 'hide_empty_venue',
						'type'       => 'checkbox',
						'title'      => esc_html__('Hide Empty Venues', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Check to hide the venue those don\'t have any product.', 'event-venue-showcase'),
						'default'	=> true,
					),
					array(
						'id'         => 'venue_limit',
						'type'       => 'number',
						'title'      => esc_html__('Venue Limit', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Number of total items to display. Leave it empty to show all found items.', 'event-venue-showcase'),
						'default' 		=> 9,
					),
					array(
						'id'       => 'number_of_column',
						'type'     => 'column',
						'title'    => esc_html__('Column(s)', 'event-venue-showcase'),
						'subtitle' => esc_html__('Set number of row in different devices for responsive view.', 'event-venue-showcase'),
						'default'  => array(
							'large_desktop' => '3',
							'desktop'       => '3',
							'laptop'        => '2',
							'tablet'        => '2',
							'mobile'        => '1',
						),
						'min'      => '1',
					),

					array(
						'id'       => 'order_by',
						'type'     => 'select',
						'title'    => esc_html__('Order By', 'event-venue-showcase'),
						'subtitle' => esc_html__('Select an order by option.', 'event-venue-showcase'),
						'options'  => array(
							'rand' => esc_html__('Random', 'event-venue-showcase'),
							'date' => esc_html__('Date', 'event-venue-showcase'),
							'name' => esc_html__('Name', 'event-venue-showcase'),
						),
						'default'  => 'menu_order',
					),
					array(
						'id'       => 'order',
						'type'     => 'select',
						'title'    => esc_html__('Order', 'event-venue-showcase'),
						'options'  => array(
							'ASC'  => esc_html__('Ascending', 'event-venue-showcase'),
							'DESC' => esc_html__('Descending', 'event-venue-showcase'),
						),
						'default'  => 'DESC',
						'subtitle' => esc_html__('Select an order option.', 'event-venue-showcase'),
					),
					array(
						'id'         => 'enable_preloader',
						'type'       => 'switcher',
						'title'      => esc_html__('Preloader', 'event-venue-showcase'),
						'subtitle'   => esc_html__('Event Venue will be hidden until page load completed and ajax pagination.', 'event-venue-showcase'),
						'text_on'    => esc_html__('Enabled', 'event-venue-showcase'),
						'text_off'   => esc_html__('Disabled', 'event-venue-showcase'),
						'text_width' => 96,
						'default'    => true,
					),
				),
			)
		);
	}
}
