<?php

/**
 * Views class for Shortcode generator options.
 *
 * @link       https://themeatelier.net
 * @since      1.0.0
 *
 * @package event-venue-showcase
 * @subpackage event-venue-showcase/Admin/Views
 * @author     ThemeAtelier<themeatelierbd@gmail.com>
 */

namespace ThemeAtelier\EventVenueShowcase\Admin\Views;

use ThemeAtelier\EventVenueShowcase\Admin\Framework\Classes\EVS;
use ThemeAtelier\EventVenueShowcase\Admin\Views\General;
use ThemeAtelier\EventVenueShowcase\Admin\Views\Display;
use ThemeAtelier\EventVenueShowcase\Admin\Views\Carousel;

/**
 * Views class to create all metabox options for Event venue Shortcode generator.
 */
class Views
{

	/**
	 * Create metabox for the Generator options.
	 *
	 * @param string $prefix Metabox key prefix.
	 * @return void
	 */
	public static function view_heading($prefix)
	{
		EVS::createMetabox(
			$prefix,
			array(
				'title'        => esc_html__('Views Generator Header', 'event-venue-showcase'),
				'post_type'    => 'event_venue',
				'class'        => 'evs-metabox-tabs',
				'nav'          => 'inline',
				'show_restore' => false,
				'context'      => 'normal',
			)
		);

		Heading::section($prefix);
	}

	/**
	 * Create metabox for the Generator options.
	 *
	 * @param string $prefix Metabox key prefix.
	 * @return void
	 */
	public static function metaboxes($prefix)
	{
	
			$option = array(
				'popup'       => esc_html__('Popup', 'event-venue-showcase'),
				'none'        => esc_html__('None (no link action)', 'event-venue-showcase'),
			);

			if (in_array('events-calendar-pro/events-calendar-pro.php', apply_filters('active_plugins', get_option('active_plugins')))) {
				$option = array(
					'popup'       => esc_html__('Popup', 'event-venue-showcase'),
					'single_page' => esc_html__('Single Page', 'event-venue-showcase'),
					'none'        => esc_html__('None (no link action)', 'event-venue-showcase'),
				);
			}

		


		EVS::createMetabox(
			$prefix,
			array(
				'title'        => esc_html__('Views Generator Settings', 'event-venue-showcase'),
				'post_type'    => 'event_venue',
				'theme'        => 'light',
				'class'        => 'event-venues-metabox-tabs',
				'nav'          => 'inline',
				'show_restore' => false,
			)
		);

		// Serialized Ahead!
		General::section($prefix);
		Display::section($prefix);
		Carousel::section($prefix);
		DetailPageSetting::section($prefix, $option);
	}
}
