<?php

/**
 * The frontend facing venue address file.
 *
 * The output HTML for the address of venue.
 *
 * @link       https://themeatelier.net
 * @since      1.0.0
 *
 * @package event-venue-showcase
 * @subpackage event-venue-showcase/Frontend/templates/venue
 * @author     ThemeAtelier<themeatelierbd@gmail.com>
 */

$venue_id = $venue->ID;
$address = tribe_get_address($venue_id);
$city = tribe_get_city($venue_id);
$country = tribe_get_country($venue_id);
$state = tribe_get_state($venue_id);
$zip = tribe_get_zip($venue_id);
$google_map = tribe_embed_google_map($venue_id);
$website_link = tribe_get_venue_website_link($venue_id);
$google_maps_base_url = 'https://www.google.com/maps/search/?api=1&query=';
$full_address = urlencode("$address, $city, $state, $country, $zip");
$google_maps_url = $google_maps_base_url . $full_address;

$address_parts = array();
if (!empty($venue_address)) :
    foreach ($venue_address as $address_type) {
        switch ($address_type) {
            case 'address':
                if ($venue_address) :
                    $address_parts[] = esc_html($address);
                endif;
                break;
            case 'city':
                if ($city) :
                    $address_parts[] = esc_html($city);
                endif;
                break;
            case 'country':
                if ($country) :
                    $address_parts[] = esc_html($country);
                endif;
                break;
            case 'state':
                if ($state) :
                    $address_parts[] = esc_html($state);
                endif;
                break;
            case 'zip':
                if ($zip) :
                    $address_parts[] = esc_html($zip);
                endif;
                break;
            case 'google_map':
                if ($google_map) :
                    $address_parts[] = '<a href="' . esc_url($google_maps_url) . '" target="_blank">' . esc_html($venue_google_mam_text) . '</a>';
                endif;
                break;
            case 'website_link':
                if ($website_link) :
                    $address_parts[] = esc_html($website_link);
                endif;
                break;
        }
    }
endif;

if ($address_parts[0]) {
    // Join the parts with a comma and output them
    echo '<div class="evs_address">';
    echo '<i class="' . esc_attr($venue_address_icon) . '"></i>';
    echo '<div>';
    echo wp_kses_post(implode(', ', $address_parts));
    echo '</div>';
    echo '</div>';
}
