<?php

/**
 * The frontend facing venue file to show term item.
 *
 * It shows the frontend output of plugin for grid layout.
 *
 * @link       https://themeatelier.net
 * @since      1.0.0
 *
 * @package event-venue-showcase
 * @subpackage event-venue-showcase/Frontend/templates/venue
 * @author     ThemeAtelier<themeatelierbd@gmail.com>
 */

use ThemeAtelier\EventVenueShowcase\Frontend\Manager;

if ($popup_venue_sorter) {
	foreach ($popup_venue_sorter as $content_key => $content_sorter) {
		switch ($content_key) {
			case 'popup_evs_thumb':
				$show_venue_image = isset($content_sorter['popup_show_venue_image']) ? $content_sorter['popup_show_venue_image'] : '';
				if ($show_venue_image) {
					$thumb_id = get_post_thumbnail_id($venue);
					$thumb_full_src    = wp_get_attachment_image_src($thumb_id, 'full');
					$image        = !empty($thumb_full_src[0]) ? $thumb_full_src[0] : '';
					$image_width  = !empty($thumb_full_src[1]) ? $thumb_full_src[1] : 600;
					$image_height = !empty($thumb_full_src[2]) ? $thumb_full_src[2] : 400;
					if ($image) {
						echo '<div class="evs_term_image text-center">';
?>
						<img src="<?php echo esc_url($image); ?>" alt="<?php echo esc_html(get_the_title($venue)); ?>" width="<?php echo esc_attr($image_width); ?>" height="<?php echo esc_attr($image_height); ?>" class="evs-thumb" />
					<?php
						echo '</div>';
					}
				}
				break;
			case 'popup_evs_title':
				$show_venue_title = isset($content_sorter['popup_show_venue_title']) ? $content_sorter['popup_show_venue_title'] : '';
				if ($show_venue_title) {
					?>
					<h3 class="evs_title">
						<?php echo esc_html(get_the_title($venue)); ?>
						<?php if ($event_count && $events_count) : ?>
							(<?php echo esc_html($events_count) ?>)
						<?php endif; ?>
					</h3>
				<?php
				}
				break;
			case 'popup_evs_address':
				$show_venue_address = isset($content_sorter['popup_show_venue_address']) ? $content_sorter['popup_show_venue_address'] : '';
				if ($show_venue_address) {
					include Manager::evs_locate_template('venue/address.php');
				}
				break;
			case 'popup_evs_phone':
				$show_phone_number = isset($content_sorter['popup_show_phone_number']) ? $content_sorter['popup_show_phone_number'] : '';
				if ($show_phone_number) {
					include Manager::evs_locate_template('venue/phone.php');
				}
				break;
			case 'popup_evs_website':
				$show_venue_website = isset($content_sorter['popup_show_venue_website']) ? $content_sorter['popup_show_venue_website'] : '';
				$website_text = isset($content_sorter['popup_website_text']) ? $content_sorter['popup_website_text'] : '';
				if ($show_venue_website) {
					include Manager::evs_locate_template('venue/website.php');
				}
				break;
			case 'popup_evs_map':
				$show_venue_map = isset($content_sorter['popup_show_venue_map']) ? $content_sorter['popup_show_venue_map'] : '';
				if ($show_venue_map) {
					include Manager::evs_locate_template('venue/map.php');
				}
				break;
			case 'popup_evs_description':
				$show_venue_content = isset($content_sorter['popup_show_venue_content']) ? $content_sorter['popup_show_venue_content'] : '';
				$evs_content_type = isset($content_sorter['popup_evs_content_type']) ? $content_sorter['popup_evs_content_type'] : '';
				$evs_content_length_type = isset($content_sorter['popup_evs_content_length_type']) ? $content_sorter['popup_evs_content_length_type'] : '';
				$evs_content_limit = isset($content_sorter['popup_evs_content_limit']) ? $content_sorter['popup_evs_content_limit'] : '';
				$evs_content_ellipsis = isset($content_sorter['popup_evs_content_ellipsis']) ? $content_sorter['popup_evs_content_ellipsis'] : '';
				$evs_content_characters_limit = isset($content_sorter['popup_evs_content_characters_limit']) ? $content_sorter['popup_evs_content_characters_limit'] : '';
				if ($show_venue_content) {
					include Manager::evs_locate_template('venue/description.php');
				}
				break;
			case 'this_location_event':
				if ($show_current_venue_events) : ?>
					<div class="popup_event_list">
						<?php if ($events_title) : ?>
							<h3 class="popup_event_list_title"><?php echo esc_html($events_title_text); ?></h3>
						<?php endif; ?>
						<?php
						if ($events_query->have_posts()) :
							while ($events_query->have_posts()) : $events_query->the_post();

								$event_date = tribe_get_start_date(null, false, 'M d');
								$date_parts = explode(' ', $event_date);
								$month = $date_parts[0];
								$day = $date_parts[1];
						?>
								<div class="list_wrapper <?php echo esc_attr($popup_evs_thumb_gray_scale); ?>" data-id="<?php echo esc_attr($venue_id); ?>">
									<div class="event_date">
										<span class="ev-mo"><?php echo esc_html($month); ?></span>
										<span class="ev-day"><?php echo esc_html($day); ?></span>
									</div>
									<div class="event_details">
										<h3><a href="<?php the_permalink(); ?>"><?php echo esc_html(the_title()); ?></a></h3>
										<?php
										$excerpt = esc_html(get_the_excerpt());
										echo '<p>' . wp_kses_post(wp_trim_words($excerpt, $excerpt_length)) . '</p>';
										?>
									</div>
								</div>
						<?php
							endwhile;
							wp_reset_postdata();
						endif;
						?>
					</div>
				<?php endif;
				if ($events_count > $par_page_event && $show_lode_more_button && !empty($lode_more_button_text)) : ?>
					<input type="hidden" id="post_id" value="<?php echo esc_attr($post_id); ?>">
					<button id="load-more"><?php echo esc_html($lode_more_button_text) ?></button>
	<?php endif;
				break;
		}
	}
}
if ($popup_close_button) {
	?>
	<button title="<?php esc_html_e('Close (Esc)', 'event-venue-showcase') ?>" type="button" class="mfp-close evs-popup-close">&#215;</button>
<?php
}
